@@ -48,7 +48,12 @@ let percent_regex = new RegExp(
 // Core client
 // ===========
 // Given an ID to use, run the CodeChat Client.
-function run_client(id, ws_address) {
+function run_client(
+    // The ID of the CodeChat Client for this window.
+    id,
+    // The port to use for a websocket connection to the CodeChat Server.
+    ws_port
+) {
     // Set up variables used by the functions below
     // --------------------------------------------
     // Get commonly-used nodes in the DOM.
@@ -78,7 +83,9 @@ function run_client(id, ws_address) {
     set_splitter_percent(splitter_size[errors_or_warnings]);
 
     // Create a websocket to communicate with the CodeChat Server.
-    let ws = new ReconnectingWebSocket(ws_address);
+    let ws = new ReconnectingWebSocket(
+        `ws://${window.location.hostname}:${ws_port}`
+    );
 
     // Identify this client on connection.
     ws.onopen = () => {
@@ -110,10 +117,16 @@ function run_client(id, ws_address) {
             let [scrollX, scrollY] = getScroll();
             // See ideas in https://stackoverflow.com/a/16822995. Works for same-domain only.
             outputElement.onload = function () {
-                // Only run this once, not every time the user navigates in the browser.
-                outputElement.onload = undefined;
                 if (is_user_navigation) {
-                    console.log("CodeChat Client: TODO: User navigation.");
+                    console.log("CodeChat Client: User navigation.");
+                    const outputElement_location =
+                        outputElement.contentWindow.window.location;
+                    // Only send a message if the navigation occurs in the local server.
+                    if (
+                        window.location.origin == outputElement_location.origin
+                    ) {
+                        browser_navigation(outputElement_location.pathname);
+                    }
                 } else {
                     status_message.innerHTML = "Build complete.";
                     build_progress.style.display = "none";
@@ -258,7 +271,7 @@ function run_client(id, ws_address) {
 
     // Send a message to the CodeChat server.
     function send_to_codechat_server(
-        // A string, indentifying the type of message.
+        // A string, identifying the type of message.
         msg,
         // Message-specific data to send. Must be JSON-encodable.
         data
@@ -276,13 +289,19 @@ function run_client(id, ws_address) {
         });
     };
 
-    // The let statements below makes these accessible globally.
+    // The ``var`` statement below makes some of these accessible globally.
     navigate_to_error = function (file_path, line) {
         send_to_codechat_server("navigate_to_error", {
             file_path: file_path,
             line: line,
         });
     };
+
+    browser_navigation = function (pathname) {
+        send_to_codechat_server("browser_navigation", {
+            pathname: pathname,
+        });
+    };
 }
 
 // Globally-accessible functions (see above). These must be declared as ``var`` (not ``let``) due to (I assume) scoping rules I don't understand.
